EXPORTS
	PlaceholderForRemovedExport1__14CMDXMLDocumentR7MXMLDtd @ 1 NONAME R3UNUSED ; CMDXMLDocument::PlaceholderForRemovedExport1(MXMLDtd &)
	AppendL__19CMDXMLCharacterDataR7TDesC16 @ 2 NONAME R3UNUSED ; CMDXMLCharacterData::AppendL(TDesC16 &)
	AttributeDetails__13CMDXMLElementiR7TPtrC16T2 @ 3 NONAME ; CMDXMLElement::AttributeDetails(int, TPtrC16 &, TPtrC16 &)
	CanElementHaveChildren__C14CMDXMLDocumentRC7TDesC16 @ 4 NONAME R3UNUSED ; CMDXMLDocument::CanElementHaveChildren(TDesC16 const &) const
	CheckChildren__13CMDXMLElement @ 5 NONAME R3UNUSED ; CMDXMLElement::CheckChildren(void)
	CheckChildren__19CMDXMLCharacterData @ 6 NONAME R3UNUSED ; CMDXMLCharacterData::CheckChildren(void)
	CheckImmediateChildren__13CMDXMLElement @ 7 NONAME R3UNUSED ; CMDXMLElement::CheckImmediateChildren(void)
	Data__19CMDXMLCharacterData @ 8 NONAME R3UNUSED ; CMDXMLCharacterData::Data(void)
	E32Dll__F10TDllReason @ 9 NONAME R3UNUSED ; E32Dll(TDllReason)
	FindIndex__13CMDXMLElementRC7TDesC16 @ 10 NONAME R3UNUSED ; CMDXMLElement::FindIndex(TDesC16 const &)
	GetAttribute__C13CMDXMLElementRC7TDesC16R7TPtrC16 @ 11 NONAME R3UNUSED ; CMDXMLElement::GetAttribute(TDesC16 const &, TPtrC16 &) const
	InsertBefore__10CMDXMLNodeP10CMDXMLNodeT1 @ 12 NONAME R3UNUSED ; CMDXMLNode::InsertBefore(CMDXMLNode *, CMDXMLNode *)
	InsertL__19CMDXMLCharacterDataiR7TDesC16 @ 13 NONAME R3UNUSED ; CMDXMLCharacterData::InsertL(int, TDesC16 &)
	IsAttributeSpecified__C13CMDXMLElementRC7TDesC16 @ 14 NONAME R3UNUSED ; CMDXMLElement::IsAttributeSpecified(TDesC16 const &) const
	Length__19CMDXMLCharacterData @ 15 NONAME R3UNUSED ; CMDXMLCharacterData::Length(void)
	NewLC__10CMDXMLTextP14CMDXMLDocument @ 16 NONAME R3UNUSED ; CMDXMLText::NewLC(CMDXMLDocument *)
	NewLC__13CMDXMLCommentP14CMDXMLDocument @ 17 NONAME R3UNUSED ; CMDXMLComment::NewLC(CMDXMLDocument *)
	NewLC__13CMDXMLElementiP14CMDXMLDocumentG7TPtrC16 @ 18 NONAME ; CMDXMLElement::NewLC(int, CMDXMLDocument *, TPtrC16)
	NewLC__14CMDXMLDocumentR7MXMLDtd @ 19 NONAME R3UNUSED ; CMDXMLDocument::NewLC(MXMLDtd &)
	NewLC__18CMDXMLCDATASectionP14CMDXMLDocument @ 20 NONAME R3UNUSED ; CMDXMLCDATASection::NewLC(CMDXMLDocument *)
	NewLC__21CMDXMLDocumentElementP14CMDXMLDocument @ 21 NONAME R3UNUSED ; CMDXMLDocumentElement::NewLC(CMDXMLDocument *)
	NewLC__27CMDXMLProcessingInstructionP14CMDXMLDocument @ 22 NONAME R3UNUSED ; CMDXMLProcessingInstruction::NewLC(CMDXMLDocument *)
	NewL__10CMDXMLTextP14CMDXMLDocument @ 23 NONAME R3UNUSED ; CMDXMLText::NewL(CMDXMLDocument *)
	NewL__13CMDXMLCommentP14CMDXMLDocument @ 24 NONAME R3UNUSED ; CMDXMLComment::NewL(CMDXMLDocument *)
	NewL__13CMDXMLElementiP14CMDXMLDocumentG7TPtrC16 @ 25 NONAME ; CMDXMLElement::NewL(int, CMDXMLDocument *, TPtrC16)
	NewL__14CMDXMLDocumentR7MXMLDtd @ 26 NONAME R3UNUSED ; CMDXMLDocument::NewL(MXMLDtd &)
	NewL__18CMDXMLCDATASectionP14CMDXMLDocument @ 27 NONAME R3UNUSED ; CMDXMLCDATASection::NewL(CMDXMLDocument *)
	NewL__21CMDXMLDocumentElementP14CMDXMLDocument @ 28 NONAME R3UNUSED ; CMDXMLDocumentElement::NewL(CMDXMLDocument *)
	NewL__27CMDXMLProcessingInstructionP14CMDXMLDocument @ 29 NONAME R3UNUSED ; CMDXMLProcessingInstruction::NewL(CMDXMLDocument *)
	NextSameTypeSibling__10CMDXMLNode @ 30 NONAME R3UNUSED ; CMDXMLNode::NextSameTypeSibling(void)
	NodeName__10CMDXMLNode @ 31 NONAME R3UNUSED ; CMDXMLNode::NodeName(void)
	NumAttributes__13CMDXMLElement @ 32 NONAME R3UNUSED ; CMDXMLElement::NumAttributes(void)
	PreviousSameTypeSibling__10CMDXMLNode @ 33 NONAME R3UNUSED ; CMDXMLNode::PreviousSameTypeSibling(void)
	RemoveAttribute__13CMDXMLElementRC7TDesC16 @ 34 NONAME R3UNUSED ; CMDXMLElement::RemoveAttribute(TDesC16 const &)
	RemoveChild__10CMDXMLNodeP10CMDXMLNode @ 35 NONAME R3UNUSED ; CMDXMLNode::RemoveChild(CMDXMLNode *)
	ReplaceChild__10CMDXMLNodeP10CMDXMLNodeT1 @ 36 NONAME R3UNUSED ; CMDXMLNode::ReplaceChild(CMDXMLNode *, CMDXMLNode *)
	ReplaceL__19CMDXMLCharacterDataiiR7TDesC16 @ 37 NONAME ; CMDXMLCharacterData::ReplaceL(int, int, TDesC16 &)
	SetAttributeL__13CMDXMLElementRC7TDesC16T1 @ 38 NONAME R3UNUSED ; CMDXMLElement::SetAttributeL(TDesC16 const &, TDesC16 const &)
	SetDataL__19CMDXMLCharacterDataR7TDesC16 @ 39 NONAME R3UNUSED ; CMDXMLCharacterData::SetDataL(TDesC16 &)
	SetDocTypeTagL__14CMDXMLDocumentRC7TDesC16 @ 40 NONAME R3UNUSED ; CMDXMLDocument::SetDocTypeTagL(TDesC16 const &)
	SetNodeNameL__10CMDXMLNodeRC7TDesC16 @ 41 NONAME R3UNUSED ; CMDXMLNode::SetNodeNameL(TDesC16 const &)
	SetVersionTagL__14CMDXMLDocumentRC7TDesC16 @ 42 NONAME R3UNUSED ; CMDXMLDocument::SetVersionTagL(TDesC16 const &)
	ValidElementNameL__C14CMDXMLDocumentRC7TDesC16 @ 43 NONAME R3UNUSED ; CMDXMLDocument::ValidElementNameL(TDesC16 const &) const
	"_._10CMDXMLNode" @ 44 NONAME R3UNUSED ; CMDXMLNode::~CMDXMLNode(void)
	"_._10CMDXMLText" @ 45 NONAME R3UNUSED ; CMDXMLText::~CMDXMLText(void)
	"_._13CMDXMLComment" @ 46 NONAME R3UNUSED ; CMDXMLComment::~CMDXMLComment(void)
	"_._13CMDXMLElement" @ 47 NONAME R3UNUSED ; CMDXMLElement::~CMDXMLElement(void)
	"_._14CMDXMLDocument" @ 48 NONAME R3UNUSED ; CMDXMLDocument::~CMDXMLDocument(void)
	"_._18CMDXMLCDATASection" @ 49 NONAME R3UNUSED ; CMDXMLCDATASection::~CMDXMLCDATASection(void)
	"_._19CMDXMLCharacterData" @ 50 NONAME R3UNUSED ; CMDXMLCharacterData::~CMDXMLCharacterData(void)
	"_._21CMDXMLDocumentElement" @ 51 NONAME R3UNUSED ; CMDXMLDocumentElement::~CMDXMLDocumentElement(void)
	"_._27CMDXMLProcessingInstruction" @ 52 NONAME R3UNUSED ; CMDXMLProcessingInstruction::~CMDXMLProcessingInstruction(void)
	__13CMDXMLElementiP14CMDXMLDocument @ 53 NONAME R3UNUSED ; CMDXMLElement::CMDXMLElement(int, CMDXMLDocument *)
	AppendChild__10CMDXMLNodeP10CMDXMLNode @ 54 NONAME R3UNUSED ; CMDXMLNode::AppendChild(CMDXMLNode *)
	FirstChildOfType__13CMDXMLElementRC7TDesC16 @ 55 NONAME R3UNUSED ; CMDXMLElement::FirstChildOfType(TDesC16 const &)
	LastChildOfType__13CMDXMLElementRC7TDesC16 @ 56 NONAME R3UNUSED ; CMDXMLElement::LastChildOfType(TDesC16 const &)
	NewLC__14CMDXMLDocument @ 57 NONAME R3UNUSED ; CMDXMLDocument::NewLC(void)
	NewL__14CMDXMLDocument @ 58 NONAME R3UNUSED ; CMDXMLDocument::NewL(void)
	PlaceholderForRemovedExport2__14CMDXMLDocument @ 59 NONAME R3UNUSED ; CMDXMLDocument::PlaceholderForRemovedExport2(void)
	SetAttributeL__13CMDXMLElementRC7TDesC16T1i @ 60 NONAME ; CMDXMLElement::SetAttributeL(TDesC16 const &, TDesC16 const &, int)

